% Online regret lower bound simulator
% Code for Figures 1 and 2 in New Potential-Based Bounds for the Geometric
% -Stopping Version of Prediction with Expert Advice
clc;
clear;

%fname = 'smallN_geom'; 
fname = 'medN_geom_lb';
addpath('./libs/');   
figdir       = './figs/';
switch fname
    case 'medN_geom_lb'
        N = 2:10:720; 
        delta = 1/10^6;
    case 'smallN_geom'
        N = 2:30; 
        delta = 1/10^6;
end

EWAP_ub  = @(n) sqrt (2* log(n)); 
EWAP_lb  = @(n) sqrt (log(n)/2); 
fig1  = figure;

switch fname
    case 'medN_geom_lb'
        plot(N, EWAP_ub(N)*sqrt(1-delta), '*g', ...
             N, screened_poisson_lb(N, delta)*sqrt(delta),'b',...
             N, screened_poisson_lb_nonasy(N, delta)*sqrt(delta),'ob',...
             N, EWAP_lb (N), 'dg');
       legend_cell(1)  = {'Exp u.b. (fixed $N$ and $\delta$)'}; 
       legend_cell(2)  = {'l.b. for screened poisson based adversary $a^s$ (fixed $N$ and leading order term in $\delta$)'};
       legend_cell(3)  = {'l.b. for screened poisson based adversary $a^s$ (fixed $N$ and $\delta$)'};
       legend_cell(4)  = {'l.b. of optimal adversary against Exp-based player in Gravin et al.   (fixed $N$ and $\delta$)'};
       leg=legend(legend_cell,'Location', 'southeast');
        ylabel('$C_N$ ',  'Interpreter', 'latex');
        titleStr = ['Lower bounds ($\frac{1}{\delta}= ', sprintf(' 10^%0.5g$)', log10(1/delta))];
 case 'smallN_geom'

        plot( N, EWAP_ub(N)*sqrt(1-delta), '*g',...
              N, screened_poisson_ub_nonasy(N, delta)*sqrt(delta),'xb',...
              N, screened_poisson_ub(N, delta)*sqrt(delta),'--b',...
              N, max_geom_ub_nonasy(N, delta)*sqrt(delta), '+k',...
              4, pi /(2* sqrt(2)), 'dr', ...
              N, max_geom_lb_nonasy(N, delta)*sqrt(delta),'sk',...
              N, screened_poisson_lb_nonasy(N, delta)*sqrt(delta),'ob',...
              N, EWAP_lb (N), 'dg');
       legend_cell(1)  = {'Exp u.b. (fixed $N$ and $\delta$)'}; 
       legend_cell(2)  = {'u.b. for screened poisson player $p^s$ (fixed $N$ and $\delta$)'};
       legend_cell(3)  = {'u.b. for screened poisson player $p^s$ (fixed $N$ and leading order in $\delta$)'};
       legend_cell(4)  = {'u.b. for max potential based player $p^m$ (fixed $N$ and  $\delta$)'};
       legend_cell(5)  = {'optimal regret in Bayrakktar et al. (fixed $N=4$ and leading order in $\delta$)'};
       legend_cell(6)  = {'l.b. for max-potential based adversary $a^m$ (fixed $N$ and $\delta$)'};
       legend_cell(7)  = {'l.b. for screened poisson based adversary $a^s$ (fixed $N$ and $\delta$)'};
       legend_cell(8)  = {'l.b. of optimal adversary against Exp-based player in Gravin et al.   (fixed $N$ and $\delta$)'};
     
       leg=legend(legend_cell,'Location', 'northwest');
       
        
        
        ylabel('$C_N$',  'Interpreter', 'latex');
        titleStr = ['Bounds for small N ($\frac{1}{\delta}= ', sprintf(' 10^{%0.5g}$)', log10(1/delta))];
end

xlim ([min(N)-.5, max(N)+.5 ] );

  
set(leg,'Interpreter','latex');
title (titleStr, 'Interpreter', 'latex');
xlabel('N ', 'Interpreter', 'latex');
 
tightfig(fig1); 
saveas(fig1, [figdir, fname], 'pdf'); 
